@@ -71,8 +71,8 @@ def main():
       lenguage = input(f"Pon el idioma en el que esta \n * ruby\n * python\n * nodejs\n * scala\n * clojure\n * cs\n * php\n MIRAR DOCS URGENTE ({url}docs) :: ").strip()
       mirarSiUsuarioEsImbecil(lenguage, i=True)
 
-      if args["-v"] or args["--verbose"]:
-            verbose = True
+      if "--verbose" in args:
+        verbose = True
 
       crearArchivo(lenguage, instalacion)
 
